@@ -10,9 +10,9 @@ module REXMLTests
     def test_linear_performance_space
       seq = [10000, 50000, 100000, 150000, 200000]
       assert_linear_performance(seq, rehearsal: 10) do |n|
-        REXML::Document.new("<!DOCTYPE schema SYSTEM \"foo.dtd\" [<!ATTLIST " +
+        REXML::Document.new("<!DOCTYPE root SYSTEM \"foo.dtd\" [<!ATTLIST " +
                             " " * n +
-                            " root v CDATA #FIXED \"test\">]>")
+                            " root v CDATA #FIXED \"test\">]><root/>")
       end
     end
 
@@ -23,7 +23,7 @@ module REXMLTests
                             "\t" * n +
                             "root value CDATA \"" +
                             ">" * n +
-                            "\">]>")
+                            "\">]><root/>")
       end
     end
   end
