@@ -174,7 +174,7 @@ module REXMLTests
     def test_linear_performance_top_level_gt
       seq = [10000, 50000, 100000, 150000, 200000]
       assert_linear_performance(seq, rehearsal: 10) do |n|
-        REXML::Document.new('<!-- ' + ">" * n + ' -->')
+        REXML::Document.new('<!-- ' + ">" * n + ' --><a/>')
       end
     end
 
